@@ -76,6 +76,8 @@ struct UICStruct {
 	GtkWidget *sendSMSButton;
 	GtkWidget *smsLabel;
 	GtkWidget *getSmsMenuItem;
+	GtkWidget *notebook;
+	GtkWidget *dialPadEntry;
 	gchar *smsText;
 	osso_context_t *osso_context;
 	gboolean contactInfosAvailable;
@@ -91,6 +93,7 @@ struct UICStruct {
 	gboolean noConfig;
 	gint callDetected;
 	gboolean smsDeliveryReport;
+	gboolean showDialPad;
 };
 typedef struct UICStruct UIComponents;
 
@@ -119,6 +122,7 @@ static void  quit_event( UIComponents *uic, guint callback_action, GtkWidget *me
 	gconf_client_set_bool(gconf_client, GCONF_SMS_DELIVERY_REPORT_KEY, uic->smsDeliveryReport, NULL);
 	gconf_client_set_bool(gconf_client, GCONF_NOTIFY_CALL_KEY, uic->getCalls, NULL);
 	gconf_client_set_bool(gconf_client, GCONF_NOTIFY_SMS_KEY, uic->getSms, NULL);
+	gconf_client_set_bool(gconf_client, GCONF_SHOW_DIALPAD_KEY, uic->showDialPad, NULL);
 	gconf_client_suggest_sync (gconf_client, NULL);
 	g_object_unref (gconf_client);
 
@@ -281,6 +285,18 @@ void on_menu_ignoreCI(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
 	uic->ignoreCI = !(uic->ignoreCI);
 }
 
+void on_menu_showDialPad(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
+	uic->showDialPad = !(uic->showDialPad);
+	if (gtk_notebook_get_current_page(GTK_NOTEBOOK(uic->notebook)) == 0) {
+		gtk_notebook_next_page(GTK_NOTEBOOK(uic->notebook));
+	} else {
+		if ((strlen(gtk_entry_get_text(GTK_ENTRY(uic->searchEntry))) == 0) && (strlen(gtk_entry_get_text(GTK_ENTRY(uic->dialPadEntry))) > 0)) {
+			gtk_entry_set_text(GTK_ENTRY(uic->searchEntry), gtk_entry_get_text(GTK_ENTRY(uic->dialPadEntry)));
+		}
+		gtk_notebook_prev_page(GTK_NOTEBOOK(uic->notebook));
+	}
+}
+
 gboolean useContactInfos(UIComponents *uic) {
 	gboolean useCI = TRUE;
 	gchar *c;
@@ -584,6 +600,11 @@ GtkMenu *create_menus(UIComponents *uic) {
 	g_signal_connect (G_OBJECT (menuItem), "toggled", G_CALLBACK (on_menu_ignoreCI), (gpointer) uic);
 	gtk_menu_append(menuBar, menuItem);
 	
+	menuItem = gtk_check_menu_item_new_with_label (_("Show DialPad"));
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menuItem), uic->showDialPad);
+	g_signal_connect (G_OBJECT (menuItem), "toggled", G_CALLBACK (on_menu_showDialPad), (gpointer) uic);
+	gtk_menu_append(menuBar, menuItem);
+	
 	gtk_menu_append(menuBar, gtk_separator_menu_item_new());
 	
 	menuItem = gtk_check_menu_item_new_with_label (_("Notify me on incoming call"));
@@ -722,6 +743,48 @@ void dialDBus_cb(GtkButton *widget, UIComponents *uic) {
 	
 }
 
+void on_dialPad_Dial(GtkButton *widget, UIComponents *uic) {
+	gchar *number;
+	
+	uic->gsm = TRUE;
+	number = g_strdup(gtk_entry_get_text(GTK_ENTRY(uic->dialPadEntry)));
+	dialNumber(uic, number);
+	g_free(number);
+}
+
+void on_dialPad_Number(GtkButton *widget, UIComponents *uic) {
+	gpointer data;
+	gint dialId;
+	gchar *text;
+	gchar *newText = NULL;
+	gint ln;
+	
+	data = g_object_get_data(G_OBJECT(widget), DIALPAD_DATA_KEY);
+	if (data != NULL) {
+		dialId = (gint) data;
+		text = gtk_entry_get_text(GTK_ENTRY(uic->dialPadEntry));
+		if (dialId < 10) {
+			newText = g_strdup_printf("%s%d", text, dialId);
+		} else if (dialId == 10) {
+			newText = g_strdup_printf("%s%d", text, 0);
+		} else if (dialId == 11) {
+			newText = g_strdup_printf("%s%s", text, "*");
+		} else if (dialId == 12) {
+			newText = g_strdup_printf("%s%s", text, "#");
+		} else if (dialId == 13) {
+			ln = strlen(gtk_entry_get_text(GTK_ENTRY(uic->dialPadEntry)));
+			if (ln > 0) {
+				newText = g_strndup(text,  ln - 1);
+			}
+		}
+		if (newText != NULL) {
+			gtk_entry_set_text(GTK_ENTRY(uic->dialPadEntry), newText);
+			g_free(newText);
+		}
+	}
+}
+
+
 /* another callback */
 static gboolean delete_event( GtkWidget *widget, GdkEvent *event, gpointer data ) {
 	quit_event(data, 0, NULL);
@@ -1120,8 +1183,9 @@ int main( int argc, char *argv[] ) {
 	uic->transformPlus = gconf_client_get_bool(gconf_client, GCONF_TRANSFORM_PLUS_KEY, NULL);
 	uic->ignoreCI = gconf_client_get_bool(gconf_client, GCONF_IGNORE_CONTACTINFOS_KEY, NULL);
 	uic->smsDeliveryReport = gconf_client_get_bool(gconf_client, GCONF_SMS_DELIVERY_REPORT_KEY, NULL);
-	uic->getCalls= gconf_client_get_bool(gconf_client, GCONF_NOTIFY_CALL_KEY, NULL);
-	uic->getSms= gconf_client_get_bool(gconf_client, GCONF_NOTIFY_SMS_KEY, NULL);
+	uic->getCalls = gconf_client_get_bool(gconf_client, GCONF_NOTIFY_CALL_KEY, NULL);
+	uic->getSms = gconf_client_get_bool(gconf_client, GCONF_NOTIFY_SMS_KEY, NULL);
+	uic->showDialPad = gconf_client_get_bool(gconf_client, GCONF_SHOW_DIALPAD_KEY, NULL);
 
 /* Gnokii : read the config */
 	gn_error err;
@@ -1182,9 +1246,17 @@ int main( int argc, char *argv[] ) {
 	// Menus
 	hildon_window_set_menu (appview, create_menus (uic));
 
-	// la boite gnrale
+	// Notebook
+	uic->notebook = gtk_notebook_new();
+	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(uic->notebook), FALSE);
+	gtk_notebook_set_show_border(GTK_NOTEBOOK(uic->notebook), FALSE);
+	gtk_container_add (GTK_CONTAINER (appview), uic->notebook);
+	
+	// la boite gnrale de la vue normale
 	table = gtk_table_new(9, 5, TRUE);
-	gtk_container_add (GTK_CONTAINER (appview), table);
+	gtk_notebook_append_page(GTK_NOTEBOOK(uic->notebook), table, NULL);
+	
+	//gtk_container_add (GTK_CONTAINER (appview), table);
 	gtk_table_set_col_spacings(GTK_TABLE(table), 5);
 	
 	/* Add a field & 2 buttons */
@@ -1256,8 +1328,100 @@ int main( int argc, char *argv[] ) {
 
 	gtk_table_attach_defaults( GTK_TABLE(table), scrolled_window, 0, 5, 4, 9);
 	
+	// la boite de la dialPad
+	table = gtk_table_new(5, 3, TRUE);
+	gtk_notebook_append_page(GTK_NOTEBOOK(uic->notebook), table, NULL);
+	
+	//gtk_container_add (GTK_CONTAINER (appview), table);
+	gtk_table_set_col_spacings(GTK_TABLE(table), 5);
+	
+	/* Add a field & 2 buttons */
+	uic->dialPadEntry = gtk_entry_new();
+	gtk_table_attach_defaults( GTK_TABLE(table), uic->dialPadEntry, 0, 3, 0, 1);
+
+	/* Button */
+	button = gtk_button_new_with_label ("Dial");
+	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+	g_signal_connect (G_OBJECT (button), "clicked",
+	                  G_CALLBACK (on_dialPad_Dial), (gpointer) uic);
+	gtk_widget_set_sensitive(button, !uic->noConfig);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 3, 4, 0, 1);
+	gtk_widget_grab_default(button);
+	
+	// Dial Buttons
+	button = gtk_button_new_with_label ("1");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 1);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 0, 1, 1, 2);
+	
+	button = gtk_button_new_with_label ("2");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 2);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 1, 2, 1, 2);
+	
+	button = gtk_button_new_with_label ("3");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 3);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 2, 3, 1, 2);
+	
+	button = gtk_button_new_with_label ("<-");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 13);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 3, 4, 1, 2);
+	
+	button = gtk_button_new_with_label ("4");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 4);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 0, 1, 2, 3);
+	
+	button = gtk_button_new_with_label ("5");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 5);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 1, 2, 2, 3);
+	
+	button = gtk_button_new_with_label ("6");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 6);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 2, 3, 2, 3);
+	
+	button = gtk_button_new_with_label ("7");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 7);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 0, 1, 3, 4);
+	
+	button = gtk_button_new_with_label ("8");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 8);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 1, 2, 3, 4);
+	
+	button = gtk_button_new_with_label ("9");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 9);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 2, 3, 3, 4);
+	
+	button = gtk_button_new_with_label ("*");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 11);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 0, 1, 4, 5);
+	
+	button = gtk_button_new_with_label ("0");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 10);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 1, 2, 4, 5);
+	
+	button = gtk_button_new_with_label ("#");
+	g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_dialPad_Number), (gpointer) uic);
+	g_object_set_data(G_OBJECT (button), DIALPAD_DATA_KEY, (gpointer) 12);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 2, 3, 4, 5);
+	
+	//Montre tout
 	gtk_widget_show_all (GTK_WIDGET(appview));
 	
+	//change la page si ncessaire
+	if (uic->showDialPad) {
+		gtk_notebook_set_current_page(GTK_NOTEBOOK(uic->notebook), 1);
+	}
+	
 	/* check availability and show or hide the Buttons */
 	g_idle_add ((GSourceFunc)checkAvailability_cb, uic);
 
